# fcos-suite-ui

> Reusable UI components based on React and TailwindCSS (initially funded by the Interfacer EU project).

## Component Gallery

If you want to look at all components this library has to offer, you can take a look at [our deployed component gallery (built with Ladle)](https://dev.fabcity.hamburg/fcos-suite-ui/main/), either by visiting our live deployment or running `npm run ladle` locally.

## Usage in another production project

To use any of the UI components from this package, make sure your consuming project has the following dependencies installed:

- `react`
- `react-dom`
- `@carbon/icons-react`

Also, your consuming project should import/include the fonts `IBM Plex Sans`, `Karla` and `Inter`. These fonts are not bundled into this library (however they are loaded when you run the Ladle component gallery).
If you want to use different fonts for all these components, you can overwrite the CSS variables `--plex-font`, `--karla-font` and `--inter-font` in your consuming project.

After you've done this, you should be able to install this package:

```sh
npm i -D @fchh/fcos-suite-ui
```

Now you need to import the stylesheets from this component library by importing them somewhere in your top-level index/app file:

```sh
import '@fchh/fcos-suite-ui/style.css'
```

After that, you can use any components like this:

```jsx
import { Pill } from "@fchh/fcos-suite-ui";
```

## Usage in a local development project

If you don't want to go through the hassle of alway publishing new versions to the package registry, you can also use this library locally, without any registry. In your consuming project just reference the location of this folder in the `npm install` command. If your consuming project and the component library lie next to each other in the same folder, it goes like this:

```sh
npm i -D ../fcos-suite-ui
```

If you now make any changes to the `fcos-suite-ui` folder, you need to run `npm build` again, and then your changes should show up.

## Customizable Link component

Since this is a generic Component library, it should work for many use cases (e.g. in a classic React SPA as well as in a React Native app or server rendered components). Therefore, by default it wraps all Links inside a default HTML `<a>` tag. However, if you want to use it with `react-router` or any other routing library, that uses its own Link component, you can customize the Link component in your consuming app by wrapping it with a `LinkContext` like so:

```jsx
import { LinkContext } from "@fchh/fcos-suite-ui";

export const App = ({ children }) => (
  <LinkContext.Provider
    value={{
      linkRenderFn: (linkChildren, linkTarget, linkProps) => (
        <CrazyLinkComponent to={linkTarget} {...linkProps}>
          {linkChildren}
        </CrazyLinkComponent>
      ),
    }}
  >
    {children}
  </LinkContext.Provider>
);
```
