import type { PropsWithChildren } from "react";
import { ChevronDown } from "@carbon/icons-react";
import clsx from "clsx";

export interface AccordionItemProps {
  title: string;
  open?: boolean;
  className?: string;
  id?: string;
  icon?: React.ReactNode;
}

export function AccordionItem({
  title,
  children,
  open = false,
  className,
  id,
  icon,
}: PropsWithChildren<AccordionItemProps>) {
  return (
    <details
      id={id}
      open={open}
      className={clsx(
        "fs-group fs-px-6 py-6 lg:fs-py-4 fs-border-b fs-border-grey-900",
        className,
      )}
    >
      <summary className="fs-flex fs-justify-between fs-items-center fs-cursor-pointer fs-select-none">
        <h5 className="fs-not-prose fs-font-plex fs-text-black fs-text-base fs-leading-6 fs-font-semibold fs-flex fs-gap-4 fs-items-center">
          {icon}
          {title}
        </h5>
        <div
          className={`fs-w-6 fs-transition-transform fs-ease-in fs-duration-200 fs-rotate-0 group-open:fs-rotate-180`}
        >
          <ChevronDown className="fs-w-full fs-h-auto" />
        </div>
      </summary>
      <div className="fs-pt-4 fs-pr-6 sm:fs-pr-10 lg:fs-pr-12">
        {children && (
          <div className="fs-font-plex fs-text-grey-900 fs-text-base fs-leading-5 sm:fs-leading-6 fs-font-normal">
            {children}
          </div>
        )}
      </div>
    </details>
  );
}
