import { HeroSection } from "@components/HeroSection";
import { Breadcrumbs } from "./Breadcrumbs";
import { INews } from "@interfaces/INews";
import { HorizontalNewsCard } from "@components/HorizontalNewsCard";
import { PillCloud } from "@components/PillCloud";

export interface HorizontalNewsCardListViewProps {
  titleImage: string;
  titleImageAlt?: string;
  titleImageTag?: string;
  subtitle: string;
  title: string;
  cards: INews[];
  tags?: Array<{ target?: string; title: string }>;
  breadcrumbs?: Array<{ target?: string; title: string }>;
  onTagEnable?: (tag: string) => void;
  onTagDisable?: (tag: string) => void;
  activeTags?: Array<string>;
}

export function HorizontalNewsCardListView({
  titleImage,
  titleImageAlt,
  titleImageTag,
  title,
  subtitle,
  cards,
  tags,
  breadcrumbs,
  onTagEnable,
  onTagDisable,
  activeTags,
}: HorizontalNewsCardListViewProps) {
  return (
    <div className="fs-w-full fs-mb-10 xl:fs-mb-0">
      <HeroSection
        src={titleImage}
        imageTag={titleImageTag}
        alt={titleImageAlt}
      />
      <section>
        <div className="container fs-flex fs-justify-between">
          <div className="fs-w-full xl:fs-w-[60%] fs-mx-auto">
            <Breadcrumbs className="fs-mt-4" crumbs={breadcrumbs} />
            <div className="fs-mt-10 fs-text-center">
              <span className="fs-block fs-font-karla fs-text-blue-500 text-base fs-leading-6 fs-font-semibold fs-tracking-wide fs-uppercase fs-mb-4">
                {subtitle}
              </span>
              <h2 className="fs-font-karla fs-text-grey-900 fs-text-3xl sm:fs-text-4xl xl:fs-text-6xl fs-leading-none fs-font-bold fs-tracking-tight">
                {title}
              </h2>
            </div>
            {Boolean(tags) && (
              <div className="fs-my-11 sm:fs-my-16">
                <PillCloud
                  tags={tags}
                  activeTags={activeTags}
                  onTagEnable={onTagEnable}
                  onTagDisable={onTagDisable}
                />
              </div>
            )}
            <div className="fs-mt-10 fs-mb-20 xl:fs-mb-44">
              <div className="fs-grid fs-grid-cols-1 fs-auto-rows-fr fs-gap-7">
                {cards?.map((card) => (
                  <HorizontalNewsCard
                    key={card.id}
                    variant={card.type}
                    image={card.image}
                    title={card.title}
                    description={card.description}
                    date={card.time}
                    location={card.location}
                    category={card.category}
                    href={card.href}
                  />
                ))}
              </div>
            </div>
          </div>
        </div>
      </section>
    </div>
  );
}
