import { Link } from "@components/Link";
import {
  LogoTwitter,
  LogoLinkedin,
  Email,
  LogoInstagram,
  LogoFacebook,
  LogoXing,
  LogoMastodon,
} from "@carbon/icons-react";

export interface PersonProps {
  name: string;
  position: string;
  organization?: string;
  image: string;
  email?: string;
  linkedin?: string;
  twitter?: string;
  instagram?: string;
  facebook?: string;
  mastodon?: string;
  xing?: string;
  className?: string;
}

export function Person({
  name,
  position,
  organization,
  image,
  email,
  linkedin,
  twitter,
  instagram,
  facebook,
  mastodon,
  xing,
  className,
}: PersonProps) {
  return (
    <div
      className={`fs-flex fs-flex-1 fs-flex-col fs-items-center fs-justify-between fs-not-prose fs-w-auto fs-overflow-hidden ${
        className || ""
      }`}
    >
      <div className="fs-aspect-square fs-max-w-[160px] sm:fs-max-w-[200px] md:fs-max-w-[220px]">
        <div className="fs-size-full fs-rounded-full fs-overflow-hidden">
          <img
            className="fs-size-full fs-object-cover"
            src={image}
            alt={name}
          />
        </div>
      </div>
      <div className="fs-w-full fs-flex-1 fs-flex fs-flex-col fs-justify-between">
        <h4 className="fs-mt-5 fs-mb-1 fs-font-plex fs-text-lg fs-leading-6 fs-font-medium fs-text-grey-900 fs-text-center">
          {name}
        </h4>
        {position && (
          <p className="fs-mt-1 fs-break-words fs-font-plex fs-text-lg fs-leading-6 fs-font-normal fs-text-green-500 fs-text-center">
            {position}
          </p>
        )}
        {organization && (
          <p className="fs-mt-1 fs-break-words fs-font-plex fs-text-lg fs-leading-6 fs-font-normal fs-text-green-500 fs-text-center">
            {organization}
          </p>
        )}
        {(email || linkedin || twitter) && (
          <div className="fs-mt-1.5 sm:fs-mt-3 fs-flex fs-justify-center fs-gap-2">
            {email && (
              <Link to={`mailto:${email.replace("@", "[ätt]")}`}>
                <Email
                  size={24}
                  className="fs-text-grey-400 hover:fs-text-grey-900"
                />
              </Link>
            )}
            {twitter && (
              <Link to={twitter} target="_blank" rel="noopener">
                <LogoTwitter
                  size={24}
                  className="fs-text-grey-400 hover:fs-text-grey-900"
                />
              </Link>
            )}
            {linkedin && (
              <Link to={linkedin} target="_blank" rel="noopener">
                <LogoLinkedin
                  size={24}
                  className="fs-text-grey-400 hover:fs-text-grey-900"
                />
              </Link>
            )}
            {instagram && (
              <Link to={instagram} target="_blank" rel="noopener">
                <LogoInstagram
                  size={24}
                  className="fs-text-grey-400 hover:fs-text-grey-900"
                />
              </Link>
            )}
            {facebook && (
              <Link to={facebook} target="_blank" rel="noopener">
                <LogoFacebook
                  size={24}
                  className="fs-text-grey-400 hover:fs-text-grey-900"
                />
              </Link>
            )}
            {mastodon && (
              <Link to={mastodon} target="_blank" rel="noopener">
                <LogoMastodon
                  size={24}
                  className="fs-size-full fs-text-grey-400 hover:fs-text-grey-900"
                />
              </Link>
            )}
            {xing && (
              <Link to={xing} target="_blank" rel="noopener">
                <LogoXing
                  size={24}
                  className="fs-size-full fs-text-grey-400 hover:fs-text-grey-900"
                />
              </Link>
            )}
          </div>
        )}
      </div>
    </div>
  );
}
