import clsx from "clsx";
import type { PropsWithChildren } from "react";

export interface ProseProps {
  notProse?: boolean;
  className?: string;
}

export function Prose({
  children,
  notProse,
  className,
}: PropsWithChildren<ProseProps>) {
  const TEXT_STYLE_MAPPING: Record<string, string> = {
    main: `fs-font-plex fs-text-grey-900 ${notProse ? "" : "fs-prose"}`,
    headings: "prose-headings:fs-font-karla",
    subheading: "prose-h2:fs-text-3xl",
    bullets: "prose-li:marker:fs-text-grey-900",
    blockquote:
      "prose-blockquote:fs-border-l-2 sm:prose-blockquote:fs-border-l-4 prose-blockquote:fs-border-grey-900 prose-blockquote:fs-text-sm sm:prose-blockquote:fs-text-base prose-blockquote:fs-not-italic prose-blockquote:fs-leading-5 sm:prose-blockquote:fs-leading-6 prose-blockquote:fs-font-semibold prose-blockquote:fs-tracking-wider prose-blockquote:fs-uppercase",
    code: "prose-code:before:fs-content-none prose-code:after:fs-content-none",
    image: "prose-img:fs-w-full prose-img:fs-h-auto prose-img:fs-rounded-sm",
    video: "prose-video:fs-w-full prose-video:fs-h-auto",
  };

  return (
    <article
      className={clsx(
        "fs-max-w-full",
        TEXT_STYLE_MAPPING["main"],
        TEXT_STYLE_MAPPING["headings"],
        TEXT_STYLE_MAPPING["subheading"],
        TEXT_STYLE_MAPPING["bullets"],
        TEXT_STYLE_MAPPING["blockquote"],
        TEXT_STYLE_MAPPING["image"],
        TEXT_STYLE_MAPPING["video"],
        TEXT_STYLE_MAPPING["code"],
        className,
      )}
    >
      {children}
    </article>
  );
}
